@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,9 +26,7 @@ Evolutionv3ImportData::Evolutionv3ImportData(QObject *parent, const QList<QVaria
     mPath = MailImporter::FilterEvolution_v3::defaultSettingsPath();
 }
 
-Evolutionv3ImportData::~Evolutionv3ImportData()
-{
-}
+Evolutionv3ImportData::~Evolutionv3ImportData() = default;
 
 bool Evolutionv3ImportData::foundMailer() const
 {
