@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,7 @@ TrojitaImportData::TrojitaImportData(QObject *parent, const QList<QVariant> &)
     mPath = MailImporter::OtherMailerUtil::trojitaDefaultPath();
 }
 
-TrojitaImportData::~TrojitaImportData()
-{
-}
+TrojitaImportData::~TrojitaImportData() = default;
 
 bool TrojitaImportData::foundMailer() const
 {
